The Black Code Style
====================

.. toctree::
    :hidden:

    Current style <current_style>
    Future style <future_style>

*Black* is a PEP 8 compliant opinionated formatter with its own style.

It should be noted that while keeping the style unchanged throughout releases is a
goal, the *Black* code style isn't set in stone. Sometimes it's modified in response to
user feedback or even changes to the Python language!

Documentation for both the current and future styles can be found:

- :doc:`current_style`
- :doc:`future_style`
